itkwasm.pipeline_output - itkwasm python documentation
Description: Module Contents: Classes:,, PipelineOutput,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `itkwasm.pipeline_output`

## Module Contents

### Classes

`PipelineOutput` |

### API

class itkwasm.pipeline_output.PipelineOutput
  type: itkwasm.interface_types.InterfaceTypes

    None

  data: Optional[Union[str, bytes, itkwasm.text_stream.TextStream, itkwasm.binary_stream.BinaryStream, itkwasm.text_file.TextFile, itkwasm.binary_file.BinaryFile, itkwasm.image.Image, itkwasm.mesh.Mesh, itkwasm.polydata.PolyData]]

    None

  path: Optional[str]

    None